package MT::Plugin::SKR::RoleList;

use strict;
use MT 4;
use MT::Author;
use MT::Association;
use MT::Blog;
use MT::Role;
use MT::I18N;

use vars qw( $NAME $VERSION );
($NAME) = __PACKAGE__ =~ /.+::(\w+)/;
$VERSION = '0.01';

use base qw( MT::Plugin );
my $plugin = __PACKAGE__->new ({
    id => $NAME,
    key => $NAME,
    name => $NAME,
    version => $VERSION,
    author_name => 'SKYARC System Co.,Ltd.',
    author_link => 'http://www.skyarc.co.jp/',
    doc_link => 'http://www.skyarc.co.jp/engineerblog/entry/rolelist.html',
    description => <<HTMLHEREDOC,
<__trans phrase="List up all users and their roles into CSV">
HTMLHEREDOC
    registry => {
        applications => {
            cms => {
                menus => {
                    'manage:'. $NAME => {
                        label => $NAME,
                        mode => $NAME,
                        order => 1000,
                        permission => 'administer',
                        system_permission => 'administer',
                        view => 'system',
                    },
                },
                methods => {
                    $NAME => \&_hdlr_role_list,
                },
            },
        },
    },
});
MT->add_plugin ($plugin);



###
sub _hdlr_role_list {
    my ($app) = @_;

    my $out = join (',', qw/
        author_id
        author_name
        author_nickname
        author_email
        author_status
        blog_name
        role_name
    /). "\n";
    foreach my $author (MT::Author->load (undef)) {
        foreach my $assoc (MT::Association->load ({ author_id => $author->id })) {
            my $blog = MT::Blog->load ({ id => $assoc->blog_id }) or next;
            my $role = MT::Role->load ({ id => $assoc->role_id }) or next;
            $out .= sprintf '%d,%s,"%s",%s,%d,"%s","%s"'. "\n",
                $author->id, $author->name, $author->nickname, $author->email, $author->status,
                $blog->name,
                $role->name;
        }
    }

    $app->{no_print_body} = 1;
    print "Content-type: text/csv; charset=Shift_JIS\n";
    print "Content-Disposition: attachement; filename=role_list.csv\n";
    print "\n";
    print MT::I18N::encode_text ($out, $app->charset, 'sjis');
}

1;
__END__